==> huaweicloudsdkccm-3.0.51-py2.py3-none-any.whl: huaweicloudsdkccm/v1/model/list_certificate_request.py <==
# coding: utf-8

import re
import six





class ListCertificateRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'limit': 'str',
        'name': 'str',
        'offset': 'str',
        'status': 'str'
    }

    attribute_map = {
        'limit': 'limit',
        'name': 'name',
        'offset': 'offset',
        'status': 'status'
    }

    def __init__(self, limit=None, name=None, offset=None, status=None):
        """ListCertificateRequest - a model defined in huaweicloud sdk"""
        
        

        self._limit = None
        self._name = None
        self._offset = None
        self._status = None
        self.discriminator = None

        if limit is not None:
            self.limit = limit
        if name is not None:
            self.name = name
        if offset is not None:
            self.offset = offset
        if status is not None:
            self.status = status

    @property
    def limit(self):
        """Gets the limit of this ListCertificateRequest.

        limit

        :return: The limit of this ListCertificateRequest.
        :rtype: str
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListCertificateRequest.

        limit

        :param limit: The limit of this ListCertificateRequest.
        :type: str
        """
        self._limit = limit

    @property
    def name(self):
        """Gets the name of this ListCertificateRequest.

        name

        :return: The name of this ListCertificateRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListCertificateRequest.

        name

        :param name: The name of this ListCertificateRequest.
        :type: str
        """
        self._name = name

    @property
    def offset(self):
        """Gets the offset of this ListCertificateRequest.

        offset

        :return: The offset of this ListCertificateRequest.
        :rtype: str
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListCertificateRequest.

        offset

        :param offset: The offset of this ListCertificateRequest.
        :type: str
        """
        self._offset = offset

    @property
    def status(self):
        """Gets the status of this ListCertificateRequest.

        status

        :return: The status of this ListCertificateRequest.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ListCertificateRequest.

        status

        :param status: The status of this ListCertificateRequest.
        :type: str
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCertificateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkccm-3.0.53-py2.py3-none-any.whl: huaweicloudsdkccm/v1/model/list_certificate_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCertificateRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'limit': 'str',
        'name': 'str',
        'offset': 'str',
        'status': 'str'
    }

    attribute_map = {
        'limit': 'limit',
        'name': 'name',
        'offset': 'offset',
        'status': 'status'
    }

    def __init__(self, limit=None, name=None, offset=None, status=None):
        """ListCertificateRequest - a model defined in huaweicloud sdk"""
        
        

        self._limit = None
        self._name = None
        self._offset = None
        self._status = None
        self.discriminator = None

        if limit is not None:
            self.limit = limit
        if name is not None:
            self.name = name
        if offset is not None:
            self.offset = offset
        if status is not None:
            self.status = status

    @property
    def limit(self):
        """Gets the limit of this ListCertificateRequest.

        limit

        :return: The limit of this ListCertificateRequest.
        :rtype: str
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListCertificateRequest.

        limit

        :param limit: The limit of this ListCertificateRequest.
        :type: str
        """
        self._limit = limit

    @property
    def name(self):
        """Gets the name of this ListCertificateRequest.

        name

        :return: The name of this ListCertificateRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListCertificateRequest.

        name

        :param name: The name of this ListCertificateRequest.
        :type: str
        """
        self._name = name

    @property
    def offset(self):
        """Gets the offset of this ListCertificateRequest.

        offset

        :return: The offset of this ListCertificateRequest.
        :rtype: str
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListCertificateRequest.

        offset

        :param offset: The offset of this ListCertificateRequest.
        :type: str
        """
        self._offset = offset

    @property
    def status(self):
        """Gets the status of this ListCertificateRequest.

        status

        :return: The status of this ListCertificateRequest.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ListCertificateRequest.

        status

        :param status: The status of this ListCertificateRequest.
        :type: str
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCertificateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
